pub struct AtlasConfig {
pub initial_atlas_count: usize,
pub max_atlases: usize,
pub atlas_size: (u32, u32),
pub auto_grow: bool,
pub allocation_strategy: AllocationStrategy,
}Expand description
Configuration for multiple atlas support.
Note that any values provided here are recommendations and might not be fully honored depending on the capabilities of the backend. For example, if you define the atlas size to be 8192x8192 but the device only supports texture sizes up to 4096x4096, the backend will likely decide to instead use the value that is compatible with the device.
Fields
initial_atlas_count: usizeInitial number of atlases to create.
max_atlases: usizeMaximum number of atlases to create.
atlas_size: (u32, u32)Size of each atlas texture.
auto_grow: boolWhether to automatically create new atlases when needed.
allocation_strategy: AllocationStrategyStrategy for allocating images across atlases.